==> senior_platform_authentication_ui-1.0.0.tar.gz: lib/src/presentation/mfa_authentication/widgets/mfa_authentication_code.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../../../../../../senior_platform_authentication_ui.dart';
import '../../../core/l10n/l10n_extension.dart';
import '../../../core/utils/clipboard_helper.dart';
import '../cubit/mfa_authentication_code_cubit.dart';

class MFAAuthenticationCode extends StatefulWidget {
  final MFAInfo mfaInfo;

  const MFAAuthenticationCode({
    Key? key,
    required this.mfaInfo,
  }) : super(key: key);

  @override
  State<MFAAuthenticationCode> createState() => _MFAAuthenticationCodeState();
}

class _MFAAuthenticationCodeState extends State<MFAAuthenticationCode>
    with WidgetsBindingObserver {
  String clipboardText = '';
  TextEditingController controller = TextEditingController();

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addObserver(this);
  }

  @override
  void dispose() {
    WidgetsBinding.instance.removeObserver(this);
    super.dispose();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);

    if (state == AppLifecycleState.resumed) {
      ClipboardHelper.hasText().then((value) async {
        try {
          clipboardText = await ClipboardHelper.paste();
          double.parse(clipboardText);
          if (clipboardText.length == 6) {
            getClipBoard(clipboardText);
          }
        } catch (_) {
          return;
        }
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return BlocConsumer<MFAAuthenticationCubit, MFAAuthenticationState>(
      listener: (context, state) {
        if (state.errorType != null && state.status == NetworkStatus.idle) {
          ScaffoldMessenger.of(context)
            ..hideCurrentSnackBar()
            ..showSnackBar(
              SeniorSnackBar.error(
                message: _getSnackbarErrorMessage(context, state.errorType!),
                action: SeniorSnackBarAction(
                  label: context.l10n.ok,
                  onPressed: () =>
                      ScaffoldMessenger.of(context).hideCurrentSnackBar(),
                ),
              ),
            );
        }
      },
      builder: (context, state) {
        return Padding(
          padding: const EdgeInsets.only(
            left: SeniorSpacing.normal,
            top: SeniorSpacing.xsmall,
            right: SeniorSpacing.normal,
            bottom: SeniorSpacing.normal,
          ),
          child: Column(
            children: [
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  SeniorText.h3(
                    context.l10n.insertAuthenticationCodeMessage,
                    emphasis: true,
                  ),
                  const SizedBox(
                    height: SeniorSpacing.xsmall,
                  ),
                  SeniorText.label(
                    context.l10n.insertAuthenticationCodeMessageBody,
                  ),
                ],
              ),
              Expanded(
                child: Container(
                  alignment: Alignment.center,
                  child: SeniorPinCodeFields(
                    keyboardType: TextInputType.number,
                    length: 6,
                    onComplete: (code) {},
                    onChange: (value) {},
                    onCompleteValidator: (error) async {
                      final result =
                          await context.read<MFAAuthenticationCubit>().login(
                                validationCode: controller.text,
                                tenant: widget.mfaInfo.tenant!,
                                temporaryToken: widget.mfaInfo.temporaryToken!,
                              );
                      if (!result) {
                        setState(() {
                          controller.text = '';
                        });
                      }
                      return result;
                    },
                    controller: controller,
                  ),
                ),
              ),
              Visibility(
                visible: state.status == NetworkStatus.loading,
                replacement: const SizedBox.shrink(),
                child: const SeniorLoading(),
              ),
            ],
          ),
        );
      },
    );
  }

  String _getSnackbarErrorMessage(BuildContext context, ErrorType errorType) {
    if (errorType == ErrorType.unauthorized) {
      return context.l10n.invalidCode;
    }

    return context.l10n.genericErrorMessage;
  }

  getClipBoard(String text) {
    showDialog(
      useSafeArea: true,
      barrierDismissible: false,
      useRootNavigator: true,
      context: context,
      builder: (_) {
        return SeniorModal(
          title: context.l10n.pasteCode,
          content: context.l10n.youWantToPasteCode(text),
          ghostButton: SeniorButton(
            label: context.l10n.cancel,
            fullLength: true,
            onPressed: () {
              Navigator.pop(_);
            },
            type: SeniorButtonType.ghost,
          ),
          actionButton: SeniorButton(
            label: context.l10n.paste,
            fullLength: true,
            onPressed: () {
              controller.text = text;
              Navigator.pop(_);
            },
            type: SeniorButtonType.primary,
          ),
        );
      },
    );
  }
}

==> senior_platform_authentication_ui-4.0.0.tar.gz: lib/src/presentation/mfa_authentication/widgets/mfa_authentication_code.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../../../../../../senior_platform_authentication_ui.dart';
import '../../../core/l10n/l10n_extension.dart';
import '../../../core/utils/clipboard_helper.dart';
import '../cubit/mfa_authentication_code_cubit.dart';

class MFAAuthenticationCode extends StatefulWidget {
  final MFAInfo mfaInfo;

  const MFAAuthenticationCode({
    Key? key,
    required this.mfaInfo,
  }) : super(key: key);

  @override
  State<MFAAuthenticationCode> createState() => _MFAAuthenticationCodeState();
}

class _MFAAuthenticationCodeState extends State<MFAAuthenticationCode>
    with WidgetsBindingObserver {
  String clipboardText = '';
  TextEditingController controller = TextEditingController();

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addObserver(this);
  }

  @override
  void dispose() {
    WidgetsBinding.instance.removeObserver(this);
    super.dispose();
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    super.didChangeAppLifecycleState(state);

    if (state == AppLifecycleState.resumed) {
      ClipboardHelper.hasText().then((value) async {
        try {
          clipboardText = await ClipboardHelper.paste();
          double.parse(clipboardText);
          if (clipboardText.length == 6) {
            getClipBoard(clipboardText);
          }
        } catch (_) {
          return;
        }
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return BlocConsumer<MFAAuthenticationCubit, MFAAuthenticationState>(
      listener: (context, state) {
        if (state.errorType != null && state.status == NetworkStatus.idle) {
          ScaffoldMessenger.of(context)
            ..hideCurrentSnackBar()
            ..showSnackBar(
              SeniorSnackBar.error(
                message: _getSnackbarErrorMessage(context, state.errorType!),
                action: SeniorSnackBarAction(
                  label: context.l10n.ok,
                  onPressed: () =>
                      ScaffoldMessenger.of(context).hideCurrentSnackBar(),
                ),
              ),
            );
        }
      },
      builder: (context, state) {
        return Padding(
          padding: const EdgeInsets.only(
            left: SeniorSpacing.normal,
            top: SeniorSpacing.xsmall,
            right: SeniorSpacing.normal,
            bottom: SeniorSpacing.normal,
          ),
          child: Column(
            children: [
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  SeniorText.h3(
                    context.l10n.insertAuthenticationCodeMessage,
                    emphasis: true,
                  ),
                  const SizedBox(
                    height: SeniorSpacing.xsmall,
                  ),
                  SeniorText.label(
                    context.l10n.insertAuthenticationCodeMessageBody,
                  ),
                ],
              ),
              Expanded(
                child: Container(
                  alignment: Alignment.center,
                  child: SeniorPinCodeFields(
                    keyboardType: TextInputType.number,
                    length: 6,
                    onComplete: (code) {},
                    onChange: (value) {},
                    onCompleteValidator: (error) async {
                      final result =
                          await context.read<MFAAuthenticationCubit>().login(
                                validationCode: controller.text,
                                tenant: widget.mfaInfo.tenant!,
                                temporaryToken: widget.mfaInfo.temporaryToken!,
                              );
                      if (!result) {
                        setState(() {
                          controller.text = '';
                        });
                      }
                      return result;
                    },
                    controller: controller,
                  ),
                ),
              ),
              Visibility(
                visible: state.status == NetworkStatus.loading,
                replacement: const SizedBox.shrink(),
                child: const SeniorLoading(),
              ),
            ],
          ),
        );
      },
    );
  }

  String _getSnackbarErrorMessage(BuildContext context, ErrorType errorType) {
    if (errorType == ErrorType.unauthorized) {
      return context.l10n.invalidCode;
    }

    return context.l10n.genericErrorMessage;
  }

  getClipBoard(String text) {
    showDialog(
      useSafeArea: true,
      barrierDismissible: false,
      useRootNavigator: true,
      context: context,
      builder: (_) {
        return SeniorModal(
          title: context.l10n.pasteCode,
          content: context.l10n.youWantToPasteCode(text),
          ghostButton: SeniorButton.ghost(
            label: context.l10n.cancel,
            fullWidth: true,
            onPressed: () {
              Navigator.pop(_);
            },
          ),
          actionButton: SeniorButton.primary(
            label: context.l10n.paste,
            fullWidth: true,
            onPressed: () {
              controller.text = text;
              Navigator.pop(_);
            },
          ),
        );
      },
    );
  }
}
